==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Help/About/ts/About_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>About</name>
    <message>
        <source>&amp;About</source>
        <translation type="obsolete">À &amp;propos</translation>
    </message>
    <message>
        <location filename="../About.js" line="+62"/>
        <source>About %1</source>
        <translation>À propos de %1</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Revision:</source>
        <translation>Révision :</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>%1 is based on QCAD, a free (open source) software.</source>
        <translation>%1 est basé sur QCAD, un logiciel libre (open source).</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>This means that everyone can &lt;a href=&apos;%1&apos;&gt;get involved&lt;/a&gt;!</source>
        <translation>Cela signifie que tout le monde &lt;a href=&apos;%1&apos;&gt;peut participer&lt;/a&gt;!</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Portions of this software © 2008-2016 The Qt Company Ltd.</source>
        <translation>Portions de ce logiciel © 2008-2016 The Qt Company Ltd.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The program is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.</source>
        <translation>Ce programme est distribué car potentiellement utile, mais SANS AUCUNE GARANTIE, ni explicite ni implicite, y compris les garanties de commercialisation ou d&apos;adaptation dans un but spécifique.</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Plugins</source>
        <translation>Plugins</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>No information available</source>
        <translation>Pas d&apos;information disponible</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plugin:</source>
        <translation>Plugin :</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>ID:</source>
        <translation>ID:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Description:</source>
        <translation>Description :</translation>
    </message>
    <message>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <source>Unknown</source>
        <translation>Inconnu</translation>
    </message>
    <message>
        <location line="-115"/>
        <location line="+108"/>
        <source>Version:</source>
        <translation>Version :</translation>
    </message>
    <message>
        <location line="-95"/>
        <location line="+99"/>
        <source>Qt Version:</source>
        <translation>Qt Version :</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>License:</source>
        <translation>Licence :</translation>
    </message>
    <message>
        <location line="-109"/>
        <location line="+118"/>
        <location line="+12"/>
        <source>Internet:</source>
        <translation>Internet :</translation>
    </message>
    <message>
        <location line="-128"/>
        <source>Build Date:</source>
        <translation>Date de fabrication :</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Architecture:</source>
        <translation>Architecture :</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Compiler:</source>
        <translation>Compiler :</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>%1 is an application for computer-aided design (CAD).</source>
        <translation>%1 est une application pour la conception assistée par ordinateur (CAO).</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>%1 is free (open source) software.</source>
        <translation>%1 est une logiciel libre (open source).</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Plugins and script add-ons are subject to their respective license (see &apos;Plugins&apos; tab).</source>
        <translation>Plugins et script add-ons sont soumis à leur licence respective (voir &quot;Plugins&quot; onglet).</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>All brand or product names are trademarks or registered trademarks of their respective holders.</source>
        <translation>Tous les noms d&apos;incendie ou de produits sont des marques commerciales ou des marques déposées de leurs détenteurs respectifs.</translation>
    </message>
    <message>
        <source>Portions of this software © 2013 Digia Plc.</source>
        <translation type="vanished">Portions de ce logiciel © 2013 Digia Plc.</translation>
    </message>
    <message>
        <source>Portions of this software © 2012 Nokia Corporation and/or its subsidiary(-ies).</source>
        <translation type="vanished">Portions de ce logiciel © 2012 Nokia Corporation et / ou de sa filiale(s).</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>No plugins found.</source>
        <translation>Aucun plugin trouvé.</translation>
    </message>
    <message>
        <location line="+93"/>
        <source>Active</source>
        <translation>Actif</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inactive (restart)</source>
        <translation>Inactif (redémarrer)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Trial Version:</source>
        <translation>Version d&apos;essai :</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>File:</source>
        <translation>Fichier :</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Error:</source>
        <translation>Erreur :</translation>
    </message>
    <message>
        <source>Community Edition</source>
        <translation type="vanished">Community Edition</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Script Add-Ons</source>
        <translation>Script Add-Ons</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>No script add-ons found.</source>
        <translation>Aucun script add-ons trouvés.</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Credits</source>
        <translation>Credits</translation>
    </message>
    <message>
        <location filename="../AboutInit.js" line="+2"/>
        <source>&amp;About...</source>
        <translation>À &amp;propos...</translation>
    </message>
</context>
<context>
    <name>AboutCredits</name>
    <message>
        <location filename="../AboutCredits.js" line="+4"/>
        <source>Programming</source>
        <translation>Programmation</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Translations</source>
        <translation>Traductions</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Templates</source>
        <translation>Modèles</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Icons</source>
        <translation>Icônes</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Testing, Feedback and Minor Fixes</source>
        <translation>Tests, commentaires et corrections mineures</translation>
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <source>About QCAD</source>
        <translation type="obsolete">A propos de QCAD</translation>
    </message>
    <message>
        <location filename="../AboutDialog.ui" line="+105"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation type="vanished">about:blank</translation>
    </message>
    <message>
        <location line="+134"/>
        <source>Plugins</source>
        <translation>Plugins</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Scripts</source>
        <translation>Scripts</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>System</source>
        <translation>Système</translation>
    </message>
    <message>
        <location line="-201"/>
        <source>Credits</source>
        <translation>Credits</translation>
    </message>
    <message>
        <source>About Plugins</source>
        <translation type="obsolete">À propos des plugins</translation>
    </message>
    <message>
        <source>About Script Add-Ons</source>
        <translation type="obsolete">À propos des Script Add-Ons</translation>
    </message>
</context>
<context>
    <name>AboutInit</name>
    <message>
        <source>&amp;About...</source>
        <translation type="obsolete">À &amp;propos...</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Help/About/ts/About_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>About</name>
    <message>
        <source>&amp;About</source>
        <translation type="obsolete">À &amp;propos</translation>
    </message>
    <message>
        <location filename="../About.js" line="+63"/>
        <source>About %1</source>
        <translation>À propos de %1</translation>
    </message>
    <message>
        <location line="+57"/>
        <source>Revision:</source>
        <translation>Révision :</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>%1 is based on QCAD, a free (open source) software.</source>
        <translation>%1 est basé sur QCAD, un logiciel libre (open source).</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>This means that everyone can &lt;a href=&apos;%1&apos;&gt;get involved&lt;/a&gt;!</source>
        <translation>Cela signifie que tout le monde &lt;a href=&apos;%1&apos;&gt;peut participer&lt;/a&gt;!</translation>
    </message>
    <message>
        <source>Portions of this software © 2008-2016 The Qt Company Ltd.</source>
        <translation type="vanished">Portions de ce logiciel © 2008-2016 The Qt Company Ltd.</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>The program is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.</source>
        <translation>Ce programme est distribué car potentiellement utile, mais SANS AUCUNE GARANTIE, ni explicite ni implicite, y compris les garanties de commercialisation ou d&apos;adaptation dans un but spécifique.</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Plugins</source>
        <translation>Plugins</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>No information available</source>
        <translation>Pas d&apos;information disponible</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plugin:</source>
        <translation>Plugin :</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>ID:</source>
        <translation>ID:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Description:</source>
        <translation>Description :</translation>
    </message>
    <message>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <source>Unknown</source>
        <translation>Inconnu</translation>
    </message>
    <message>
        <location line="-128"/>
        <location line="+121"/>
        <source>Version:</source>
        <translation>Version :</translation>
    </message>
    <message>
        <location line="-111"/>
        <location line="+115"/>
        <source>Qt Version:</source>
        <translation>Qt Version :</translation>
    </message>
    <message>
        <source>Portions of this software © 2008-2017 The Qt Company Ltd.</source>
        <translation type="vanished">Portions de ce logiciel © 2008-2017 The Qt Company Ltd.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>License:</source>
        <translation>Licence :</translation>
    </message>
    <message>
        <location line="-125"/>
        <location line="+134"/>
        <location line="+11"/>
        <source>Internet:</source>
        <translation>Internet :</translation>
    </message>
    <message>
        <location line="-143"/>
        <source>Build Date:</source>
        <translation>Date de fabrication :</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Architecture:</source>
        <translation>Architecture :</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Compiler:</source>
        <translation>Compiler :</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>License Key:</source>
        <translation>Clé de licence :</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>%1 is an application for computer-aided design (CAD).</source>
        <translation>%1 est une application pour la conception assistée par ordinateur (CAO).</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>%1 is free (open source) software.</source>
        <translation>%1 est une logiciel libre (open source).</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Plugins and script add-ons are subject to their respective license (see &apos;Plugins&apos; tab).</source>
        <translation>Plugins et script add-ons sont soumis à leur licence respective (voir &quot;Plugins&quot; onglet).</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>All brand or product names are trademarks or registered trademarks of their respective holders.</source>
        <translation>Tous les noms d&apos;incendie ou de produits sont des marques commerciales ou des marques déposées de leurs détenteurs respectifs.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Portions of this software © %1 The Qt Company Ltd.</source>
        <translation>Portions de ce logiciel © %1 The Qt Company Ltd.</translation>
    </message>
    <message>
        <source>Portions of this software © 2008-2018 The Qt Company Ltd.</source>
        <translation type="obsolete">Portions de ce logiciel © 2008-2017 The Qt Company Ltd. {2008-2018 ?}</translation>
    </message>
    <message>
        <source>Portions of this software © 2013 Digia Plc.</source>
        <translation type="vanished">Portions de ce logiciel © 2013 Digia Plc.</translation>
    </message>
    <message>
        <source>Portions of this software © 2012 Nokia Corporation and/or its subsidiary(-ies).</source>
        <translation type="vanished">Portions de ce logiciel © 2012 Nokia Corporation et / ou de sa filiale(s).</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>No plugins found.</source>
        <translation>Aucun plugin trouvé.</translation>
    </message>
    <message>
        <location line="+99"/>
        <source>Active</source>
        <translation>Actif</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inactive (restart)</source>
        <translation>Inactif (redémarrer)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Trial Version:</source>
        <translation>Version d&apos;essai :</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>File:</source>
        <translation>Fichier :</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Error:</source>
        <translation>Erreur :</translation>
    </message>
    <message>
        <source>Community Edition</source>
        <translation type="vanished">Community Edition</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Script Add-Ons</source>
        <translation>Script Add-Ons</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>No script add-ons found.</source>
        <translation>Aucun script add-ons trouvés.</translation>
    </message>
    <message>
        <location line="+45"/>
        <source>Credits</source>
        <translation>Credits</translation>
    </message>
    <message>
        <location filename="../AboutInit.js" line="+2"/>
        <source>&amp;About...</source>
        <translation>À &amp;propos...</translation>
    </message>
</context>
<context>
    <name>AboutCredits</name>
    <message>
        <location filename="../AboutCredits.js" line="+4"/>
        <source>Programming</source>
        <translation>Programmation</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Translations</source>
        <translation>Traductions</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Templates</source>
        <translation>Modèles</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Icons</source>
        <translation>Icônes</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Testing, Feedback and Minor Fixes</source>
        <translation>Tests, commentaires et corrections mineures</translation>
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <source>About QCAD</source>
        <translation type="obsolete">A propos de QCAD</translation>
    </message>
    <message>
        <location filename="../AboutDialog.ui" line="+105"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation type="vanished">about:blank</translation>
    </message>
    <message>
        <location line="+134"/>
        <source>Plugins</source>
        <translation>Plugins</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Scripts</source>
        <translation>Scripts</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>System</source>
        <translation>Système</translation>
    </message>
    <message>
        <location line="-201"/>
        <source>Credits</source>
        <translation>Credits</translation>
    </message>
    <message>
        <source>About Plugins</source>
        <translation type="obsolete">À propos des plugins</translation>
    </message>
    <message>
        <source>About Script Add-Ons</source>
        <translation type="obsolete">À propos des Script Add-Ons</translation>
    </message>
</context>
<context>
    <name>AboutInit</name>
    <message>
        <source>&amp;About...</source>
        <translation type="obsolete">À &amp;propos...</translation>
    </message>
</context>
</TS>
